@@ -45,7 +45,7 @@ Upstream/Server
   - need terminate machine api
   - clarify usage/working of env annotation
 """
-# License: GPL
+# License: GPLv3
 # Author: Kapil Thangavelu <kapil.foss@gmail.com>
 
 from contextlib import contextmanager
@@ -574,9 +574,10 @@ class StatusTranslator(object):
         'Status': 'agent-state',
         "MachineId": "Machine",
         'CharmURL': 'charm',
+        'StatusInfo': 'agent-state-info',
         "Number": 'port'
     }
-    remove_keys = set(['Life', "PrivateAddress"])
+    remove_keys = set(['Life', "PrivateAddress", "MinUnits"])
     skip_empty_keys = set(['StatusInfo', "Ports"])
 
     def run(self, watch):
